Method: Ore::Template::Directory#each_directory

Defined in:
lib/ore/template/directory.rb

#each_directory {|path| ... } ⇒ Object

Enumerates through the directories in the template directory.

Yields:

  • (path)

    The given block will be passed each directory path.

Yield Parameters:

  • path (String)

    The relative path of a directory within the template directory.



95
96
97
# File 'lib/ore/template/directory.rb', line 95

def each_directory(&block)
  @directories.each(&block)
end